==> haskell-serialise-0.2.6.1-34-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-serialise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 serialise
version:              0.2.6.1
visibility:           public
id:                   serialise-0.2.6.1-95J7j5kwriu6jRq4qx0NQ1
key:                  serialise-0.2.6.1-95J7j5kwriu6jRq4qx0NQ1
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           duncan@community.haskell.org, ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A binary serialisation library for Haskell values.
description:
    This package (formerly @binary-serialise-cbor@) provides pure, efficient
    serialization of Haskell values directly into @ByteString@s for storage or
    transmission purposes. By providing a set of type class instances, you can
    also serialise any custom data type you have as well.

    The underlying binary format used is the '\''Concise Binary Object
    Representation'\'', or CBOR, specified in RFC 7049. As a result,
    serialised Haskell values have implicit structure outside of the
    Haskell program itself, meaning they can be inspected or analyzed
    without custom tools.

    An implementation of the standard bijection between CBOR and JSON is provided
    by the [cborg-json](/package/cborg-json) package. Also see
    [cbor-tool](/package/cbor-tool) for a convenient command-line utility for
    working with CBOR data.

category:             Codec
abi:                  885c46c6456c228c7c649027c966c5e2
exposed:              True
exposed-modules:
    Codec.Serialise Codec.Serialise.Class Codec.Serialise.Decoding
    Codec.Serialise.Encoding Codec.Serialise.IO
    Codec.Serialise.Internal.GeneralisedUTF8 Codec.Serialise.Properties
    Codec.Serialise.Tutorial

import-dirs:          /usr/lib/ghc-9.2.8/site-local/serialise-0.2.6.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/serialise-0.2.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-serialise
hs-libraries:         HSserialise-0.2.6.1-95J7j5kwriu6jRq4qx0NQ1
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0
    cborg-0.2.9.0-IZI3dGcPpiH1v926ifjDaF containers-0.6.5.1
    ghc-prim-0.8.0 half-0.3.1-7TPjOivoFms99NUG0E66wY
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    strict-0.4.0.1-Kjf7tvWS05h7ff3Eq8uXou text-1.2.5.0
    these-1.1.1.1-FlLT2KU4YN4BBIgA41WfSa time-1.11.1.1
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-serialise/html/serialise.haddock
haddock-html:         /usr/share/doc/haskell-serialise/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-serialise-0.2.6.1-82.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-serialise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 serialise
version:              0.2.6.1
visibility:           public
id:                   serialise-0.2.6.1-4kOEedX1yLucj3WiC2KXW
key:                  serialise-0.2.6.1-4kOEedX1yLucj3WiC2KXW
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           duncan@community.haskell.org, ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A binary serialisation library for Haskell values.
description:
    This package (formerly @binary-serialise-cbor@) provides pure, efficient
    serialization of Haskell values directly into @ByteString@s for storage or
    transmission purposes. By providing a set of type class instances, you can
    also serialise any custom data type you have as well.

    The underlying binary format used is the '\''Concise Binary Object
    Representation'\'', or CBOR, specified in RFC 7049. As a result,
    serialised Haskell values have implicit structure outside of the
    Haskell program itself, meaning they can be inspected or analyzed
    without custom tools.

    An implementation of the standard bijection between CBOR and JSON is provided
    by the [cborg-json](/package/cborg-json) package. Also see
    [cbor-tool](/package/cbor-tool) for a convenient command-line utility for
    working with CBOR data.

category:             Codec
abi:                  050559c24faf73dc3f8b6953e289b41c
exposed:              True
exposed-modules:
    Codec.Serialise Codec.Serialise.Class Codec.Serialise.Decoding
    Codec.Serialise.Encoding Codec.Serialise.IO
    Codec.Serialise.Internal.GeneralisedUTF8 Codec.Serialise.Properties
    Codec.Serialise.Tutorial

import-dirs:          /usr/lib/ghc-9.4.8/site-local/serialise-0.2.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/serialise-0.2.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/serialise-0.2.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-serialise
hs-libraries:         HSserialise-0.2.6.1-4kOEedX1yLucj3WiC2KXW
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    cborg-0.2.9.0-JVQOltgIm2T3ZJWSqW2BYn containers-0.6.7
    ghc-prim-0.9.1 half-0.3.2-E7GsfcAdAl1FGkf6dksMcx
    hashable-1.4.4.0-AT2Ub72SgpTFIbLYNtgVpj
    primitive-0.8.0.0-RoAiLvCruBL00EsvIFp5f
    strict-0.5-5bEgSPcMrnbKMKlcxT9hwX text-2.0.2
    these-1.2-6tl5DKmsCDT2VnTeIBGN36 time-1.12.2
    unordered-containers-0.2.20-WenrpHtwHKIVom5hXYF7C
    vector-0.13.2.0-H3MTIE0bxkOEYwCD854O16

haddock-interfaces:   /usr/share/doc/haskell-serialise/html/serialise.haddock
haddock-html:         /usr/share/doc/haskell-serialise/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
